==> create-1.21.8-6.0.7-17-sources.jar: com/zurrtum/create/infrastructure/items/SidedInventoryWrapper.java <==
package com.zurrtum.create.infrastructure.items;

import com.zurrtum.create.infrastructure.transfer.SlotRangeCache;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.Set;
import java.util.function.Predicate;
import net.minecraft.class_1263;
import net.minecraft.class_1278;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_2350;

public record SidedInventoryWrapper(class_1263 inventory, int[] slots) implements class_1278 {
    public SidedInventoryWrapper(class_1263 inventory) {
        this(inventory, SlotRangeCache.get(inventory.method_5439()));
    }

    @Override
    public int[] method_5494(class_2350 side) {
        return slots;
    }

    @Override
    public boolean method_5492(int slot, class_1799 stack, @Nullable class_2350 dir) {
        return true;
    }

    @Override
    public boolean method_5493(int slot, class_1799 stack, class_2350 dir) {
        return true;
    }

    @Override
    public int method_5439() {
        return inventory.method_5439();
    }

    @Override
    public boolean method_5442() {
        return inventory.method_5442();
    }

    @Override
    public class_1799 method_5438(int slot) {
        return inventory.method_5438(slot);
    }

    @Override
    public class_1799 method_5434(int slot, int amount) {
        return inventory.method_5434(slot, amount);
    }

    @Override
    public class_1799 method_5441(int slot) {
        return inventory.method_5441(slot);
    }

    @Override
    public void method_5447(int slot, class_1799 stack) {
        inventory.method_5447(slot, stack);
    }

    @Override
    public int method_5444() {
        return inventory.method_5444();
    }

    @Override
    public int method_58350(class_1799 stack) {
        return inventory.method_58350(stack);
    }

    @Override
    public void method_5431() {
        inventory.method_5431();
    }

    @Override
    public boolean method_5443(class_1657 player) {
        return inventory.method_5443(player);
    }

    @Override
    public void method_5435(class_1657 player) {
        inventory.method_5435(player);
    }

    @Override
    public void method_5432(class_1657 player) {
        inventory.method_5432(player);
    }

    @Override
    public boolean method_5437(int slot, class_1799 stack) {
        return inventory.method_5437(slot, stack);
    }

    @Override
    public boolean method_49104(class_1263 hopperInventory, int slot, class_1799 stack) {
        return inventory.method_49104(hopperInventory, slot, stack);
    }

    @Override
    public int method_18861(class_1792 item) {
        return inventory.method_18861(item);
    }

    @Override
    public boolean method_18862(Set<class_1792> items) {
        return inventory.method_18862(items);
    }

    @Override
    public boolean method_43256(Predicate<class_1799> predicate) {
        return inventory.method_43256(predicate);
    }

    @Override
    public int insert(class_1799 stack) {
        return inventory.insert(stack);
    }

    @Override
    public int insert(class_1799 stack, class_2350 side) {
        return inventory.insert(stack);
    }

    @Override
    public boolean preciseInsert(class_1799 stack) {
        return inventory.preciseInsert(stack);
    }

    @Override
    public boolean preciseInsert(class_1799 stack, class_2350 side) {
        return inventory.preciseInsert(stack);
    }

    @Override
    public int count(class_1799 stack) {
        return inventory.count(stack);
    }

    @Override
    public int count(class_1799 stack, class_2350 side) {
        return inventory.count(stack);
    }

    @Override
    public int count(class_1799 stack, int maxAmount) {
        return inventory.count(stack, maxAmount);
    }

    @Override
    public int count(class_1799 stack, int maxAmount, class_2350 side) {
        return inventory.count(stack, maxAmount);
    }

    @Override
    public int countSpace(class_1799 stack) {
        return inventory.countSpace(stack);
    }

    @Override
    public int countSpace(class_1799 stack, class_2350 side) {
        return inventory.countSpace(stack);
    }

    @Override
    public int countSpace(class_1799 stack, int maxAmount) {
        return inventory.countSpace(stack, maxAmount);
    }

    @Override
    public int countSpace(class_1799 stack, int maxAmount, class_2350 side) {
        return inventory.countSpace(stack, maxAmount);
    }

    @Override
    public int extract(class_1799 stack) {
        return inventory.extract(stack);
    }

    @Override
    public int extract(class_1799 stack, class_2350 side) {
        return inventory.extract(stack);
    }

    @Override
    public boolean preciseExtract(class_1799 stack) {
        return inventory.preciseExtract(stack);
    }

    @Override
    public boolean preciseExtract(class_1799 stack, class_2350 side) {
        return inventory.preciseExtract(stack);
    }

    @Override
    @NotNull
    public java.util.Iterator<class_1799> iterator() {
        return inventory.iterator();
    }

    @Override
    @NotNull
    public java.util.Iterator<class_1799> iterator(class_2350 side) {
        return inventory.iterator();
    }
}

==> create-1.21.10-6.0.8-1-sources.jar: com/zurrtum/create/infrastructure/items/SidedInventoryWrapper.java <==
package com.zurrtum.create.infrastructure.items;

import com.zurrtum.create.infrastructure.transfer.SlotRangeCache;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.util.Set;
import java.util.function.Predicate;
import net.minecraft.class_11565;
import net.minecraft.class_1263;
import net.minecraft.class_1657;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_2350;

public record SidedInventoryWrapper(class_1263 inventory, int[] slots) implements SidedItemInventory {
    public SidedInventoryWrapper(class_1263 inventory) {
        this(inventory, SlotRangeCache.get(inventory.method_5439()));
    }

    @Override
    public int[] method_5494(class_2350 side) {
        return slots;
    }

    @Override
    public boolean method_5492(int slot, class_1799 stack, @Nullable class_2350 dir) {
        return true;
    }

    @Override
    public boolean method_5493(int slot, class_1799 stack, class_2350 dir) {
        return true;
    }

    @Override
    public int method_5439() {
        return inventory.method_5439();
    }

    @Override
    public boolean method_5442() {
        return inventory.method_5442();
    }

    @Override
    public class_1799 method_5438(int slot) {
        return inventory.method_5438(slot);
    }

    @Override
    public class_1799 method_5434(int slot, int amount) {
        return inventory.method_5434(slot, amount);
    }

    @Override
    public class_1799 method_5441(int slot) {
        return inventory.method_5441(slot);
    }

    @Override
    public void method_5447(int slot, class_1799 stack) {
        inventory.method_5447(slot, stack);
    }

    @Override
    public int method_5444() {
        return inventory.method_5444();
    }

    @Override
    public int method_58350(class_1799 stack) {
        return inventory.method_58350(stack);
    }

    @Override
    public void method_5431() {
        inventory.method_5431();
    }

    @Override
    public boolean method_5443(class_1657 player) {
        return inventory.method_5443(player);
    }

    @Override
    public void method_5435(class_11565 player) {
        inventory.method_5435(player);
    }

    @Override
    public void method_5432(class_11565 player) {
        inventory.method_5432(player);
    }

    @Override
    public boolean method_5437(int slot, class_1799 stack) {
        return inventory.method_5437(slot, stack);
    }

    @Override
    public boolean method_49104(class_1263 hopperInventory, int slot, class_1799 stack) {
        return inventory.method_49104(hopperInventory, slot, stack);
    }

    @Override
    public int method_18861(class_1792 item) {
        return inventory.method_18861(item);
    }

    @Override
    public boolean method_18862(Set<class_1792> items) {
        return inventory.method_18862(items);
    }

    @Override
    public boolean method_43256(Predicate<class_1799> predicate) {
        return inventory.method_43256(predicate);
    }

    @Override
    public int insert(class_1799 stack) {
        return inventory.insert(stack);
    }

    @Override
    public int insert(class_1799 stack, class_2350 side) {
        return inventory.insert(stack);
    }

    @Override
    public boolean preciseInsert(class_1799 stack) {
        return inventory.preciseInsert(stack);
    }

    @Override
    public boolean preciseInsert(class_1799 stack, class_2350 side) {
        return inventory.preciseInsert(stack);
    }

    @Override
    public int count(class_1799 stack) {
        return inventory.count(stack);
    }

    @Override
    public int count(class_1799 stack, class_2350 side) {
        return inventory.count(stack);
    }

    @Override
    public int count(class_1799 stack, int maxAmount) {
        return inventory.count(stack, maxAmount);
    }

    @Override
    public int count(class_1799 stack, int maxAmount, class_2350 side) {
        return inventory.count(stack, maxAmount);
    }

    @Override
    public int countSpace(class_1799 stack) {
        return inventory.countSpace(stack);
    }

    @Override
    public int countSpace(class_1799 stack, class_2350 side) {
        return inventory.countSpace(stack);
    }

    @Override
    public int countSpace(class_1799 stack, int maxAmount) {
        return inventory.countSpace(stack, maxAmount);
    }

    @Override
    public int countSpace(class_1799 stack, int maxAmount, class_2350 side) {
        return inventory.countSpace(stack, maxAmount);
    }

    @Override
    public int extract(class_1799 stack) {
        return inventory.extract(stack);
    }

    @Override
    public int extract(class_1799 stack, class_2350 side) {
        return inventory.extract(stack);
    }

    @Override
    public boolean preciseExtract(class_1799 stack) {
        return inventory.preciseExtract(stack);
    }

    @Override
    public boolean preciseExtract(class_1799 stack, class_2350 side) {
        return inventory.preciseExtract(stack);
    }

    @Override
    @NotNull
    public java.util.Iterator<class_1799> iterator() {
        return inventory.iterator();
    }

    @Override
    @NotNull
    public java.util.Iterator<class_1799> iterator(class_2350 side) {
        return inventory.iterator();
    }
}
